@@ -1,28 +1,29 @@
 """
 Class to perform various rotations of factor loading matrices.
 
-:author: Jeremy Biggs (jbiggs@ets.org)
+:author: Jeremy Biggs (jeremy.m.biggs@gmail.com)
 :author: Nitin Madnani (nmadnani@ets.org)
 :organization: Educational Testing Service
-:date: 2021-10-18
+:date: 2022-09-05
 """
 
 import numpy as np
 import scipy as sp
 from sklearn.base import BaseEstimator
 
-ORTHOGONAL_ROTATIONS = ['varimax', 'oblimax', 'quartimax', 'equamax', 'geomin_ort']
+ORTHOGONAL_ROTATIONS = ["varimax", "oblimax", "quartimax", "equamax", "geomin_ort"]
 
-OBLIQUE_ROTATIONS = ['promax', 'oblimin', 'quartimin', 'geomin_obl']
+OBLIQUE_ROTATIONS = ["promax", "oblimin", "quartimin", "geomin_obl"]
 
 POSSIBLE_ROTATIONS = ORTHOGONAL_ROTATIONS + OBLIQUE_ROTATIONS
 
 
 class Rotator(BaseEstimator):
     """
-    The Rotator class takes an (unrotated)
-    factor loading matrix and performs one
-    of several rotations.
+    Perform rotations on an unrotated factor loading matrix.
+
+    The Rotator class takes an (unrotated) factor loading matrix and
+    performs one of several rotations.
 
     Parameters
     ----------
@@ -37,54 +38,52 @@ class Rotator(BaseEstimator):
             (g) equamax (orthogonal rotation)
             (h) geomin_obl (oblique rotation)
             (i) geomin_ort (orthogonal rotation)
+
         Defaults to 'varimax'.
     normalize : bool or None, optional
-        Whether to perform Kaiser normalization
-        and de-normalization prior to and following
-        rotation. Used for varimax and promax rotations.
-        If None, default for promax is False, and default
-        for varimax is True.
-        Defaults to None.
+        Whether to perform Kaiser normalization and de-normalization prior
+        to and following rotation. Used for 'varimax' and 'promax' rotations.
+        If ``None``, default for 'promax' is ``False``, and default for
+        'varimax' is ``True``.
+        Defaults to ``None``.
     power : int, optional
-        The power to which to raise the promax loadings
-        (minus 1). Numbers should generally range form 2 to 4.
+        The exponent to which to raise the promax loadings (minus 1).
+        Numbers should generally range from 2 to 4.
         Defaults to 4.
-    kappa : int, optional
-        The kappa value for the equamax objective.
-        Ignored if the method is not 'equamax'.
+    kappa : float, optional
+        The kappa value for the 'equamax' objective. Ignored if the method
+        is not 'equamax'.
         Defaults to 0.
     gamma : int, optional
-        The gamma level for the oblimin objective.
-        Ignored if the method is not 'oblimin'.
+        The gamma level for the 'oblimin' objective. Ignored if the method
+        is not 'oblimin'.
         Defaults to 0.
     delta : float, optional
-        The delta level for geomin objectives.
-         Ignored if the method is not 'geomin_*'.
+        The delta level for 'geomin' objectives. Ignored if the method is
+        not 'geomin_*'.
         Defaults to 0.01.
     max_iter : int, optional
-        The maximum number of iterations.
-        Used for varimax and oblique rotations.
-        Defaults to `1000`.
+        The maximum number of iterations. Used for 'varimax' and 'oblique'
+        rotations.
+        Defaults to 1000.
     tol : float, optional
-        The convergence threshold.
-        Used for varimax and oblique rotations.
-        Defaults to `1e-5`.
+        The convergence threshold. Used for 'varimax' and 'oblique' rotations.
+        Defaults to 1e-5.
 
     Attributes
     ----------
-    loadings_ : numpy array, shape (n_features, n_factors)
-        The loadings matrix
-    rotation_ : numpy array, shape (n_factors, n_factors)
-        The rotation matrix
-    psi_ : numpy array or None
-        The factor correlations
-        matrix. This only exists
-        if the rotation is oblique.
+    loadings_ : :obj:`numpy.ndarray`, shape (``n_features``, ``n_factors``)
+        The loadings matrix.
+    rotation_ : :obj:`numpy.ndarray`, shape (``n_factors``, ``n_factors``)
+        The rotation matrix.
+    phi_ : :obj:`numpy.ndarray` or None
+        The factor correlations matrix. This only exists if ``method`` is
+        'oblique'.
 
     Notes
     -----
-    Most of the rotations in this class
-    are ported from R's `GPARotation` package.
+    Most of the rotations in this class are ported from R's ``GPARotation``
+    package.
 
     References
     ----------
@@ -111,16 +110,18 @@ class Rotator(BaseEstimator):
            [ 0.81372945,  0.20915845,  0.07479506]])
     """
 
-    def __init__(self,
-                 method='varimax',
-                 normalize=True,
-                 power=4,
-                 kappa=0,
-                 gamma=0,
-                 delta=0.01,
-                 max_iter=500,
-                 tol=1e-5):
-
+    def __init__(
+        self,
+        method="varimax",
+        normalize=True,
+        power=4,
+        kappa=0,
+        gamma=0,
+        delta=0.01,
+        max_iter=500,
+        tol=1e-5,
+    ):
+        """Initialize the rotator class."""
         self.method = method
         self.normalize = normalize
         self.power = power
@@ -134,7 +135,7 @@ class Rotator(BaseEstimator):
         self.rotation_ = None
         self.phi_ = None
 
-    def _oblimax_obj(self, loadings):
+    def _oblimax_obj(self, loadings):  # noqa: D401
         """
         The Oblimax function objective.
 
@@ -146,16 +147,16 @@ class Rotator(BaseEstimator):
         Returns
         -------
         gradient_dict : dict
-            A dictionary with
-            - grad : np.array
-                The gradient.
-            - criterion : float
-                The value of the criterion for the objective.
+            A dictionary containing the following keys:
+            (1) ``grad`` : :obj:`numpy.ndarray`, containing the gradients.
+            (2) ``criterion`` : float, containing the criterion for the objective.
         """
-        gradient = -(4 * loadings**3 / (np.sum(loadings**4)) - 4 * loadings /
-                     (np.sum(loadings**2)))
-        criterion = (np.log(np.sum(loadings**4)) - 2 * np.log(np.sum(loadings**2)))
-        return {'grad': gradient, 'criterion': criterion}
+        gradient = -(
+            4 * loadings**3 / (np.sum(loadings**4))
+            - 4 * loadings / (np.sum(loadings**2))
+        )
+        criterion = np.log(np.sum(loadings**4)) - 2 * np.log(np.sum(loadings**2))
+        return {"grad": gradient, "criterion": criterion}
 
     def _quartimax_obj(self, loadings):
         """
@@ -164,22 +165,20 @@ class Rotator(BaseEstimator):
         Parameters
         ----------
         loadings : array-like
-            The loading matrix
+            The loading matrix.
 
         Returns
         -------
         gradient_dict : dict
-            A dictionary with
-            - grad : np.array
-                The gradient.
-            - criterion : float
-                The value of the criterion for the objective.
+            A dictionary containing the following keys:
+            (1) ``grad`` : :obj:`numpy.ndarray`, containing the gradients.
+            (2) ``criterion`` : float, containing the criterion for the objective.
         """
-        gradient = -loadings**3
+        gradient = -(loadings**3)
         criterion = -np.sum(np.diag(np.dot((loadings**2).T, loadings**2))) / 4
-        return {'grad': gradient, 'criterion': criterion}
+        return {"grad": gradient, "criterion": criterion}
 
-    def _oblimin_obj(self, loadings):
+    def _oblimin_obj(self, loadings):  # noqa: D401
         """
         The Oblimin function objective.
 
@@ -191,60 +190,54 @@ class Rotator(BaseEstimator):
         Returns
         -------
         gradient_dict : dict
-            A dictionary with
-            - grad : np.array
-                The gradient.
-            - criterion : float
-                The value of the criterion for the objective.
+            A dictionary containing the following keys:
+            (1) ``grad`` : :obj:`numpy.ndarray`, containing the gradients.
+            (2) ``criterion`` : float, containing the criterion for the objective.
         """
         X = np.dot(loadings**2, np.eye(loadings.shape[1]) != 1)
-        if (self.gamma != 0):
+        if self.gamma != 0:
             p = loadings.shape[0]
             X = np.diag(np.full(1, p)) - np.dot(np.zeros((p, p)), X)
         gradient = loadings * X
         criterion = np.sum(loadings**2 * X) / 4
-        return {'grad': gradient, 'criterion': criterion}
+        return {"grad": gradient, "criterion": criterion}
 
-    def _quartimin_obj(self, loadings):
+    def _quartimin_obj(self, loadings):  # noqa: D401
         """
-        Quartimin function objective.
+        The Quartimin function objective.
 
         Parameters
         ----------
         loadings : array-like
-            The loading matrix
+            The loading matrix.
 
         Returns
         -------
         gradient_dict : dict
-            A dictionary with
-            - grad : np.array
-                The gradient.
-            - criterion : float
-                The value of the criterion for the objective.
+            A dictionary containing the following keys:
+            (1) ``grad`` : :obj:`numpy.ndarray`, containing the gradients.
+            (2) ``criterion`` : float, containing the criterion for the objective.
         """
         X = np.dot(loadings**2, np.eye(loadings.shape[1]) != 1)
         gradient = loadings * X
         criterion = np.sum(loadings**2 * X) / 4
-        return {'grad': gradient, 'criterion': criterion}
+        return {"grad": gradient, "criterion": criterion}
 
-    def _equamax_obj(self, loadings):
+    def _equamax_obj(self, loadings):  # noqa: D401
         """
-        Equamax function objective.
+        The Equamax function objective.
 
         Parameters
         ----------
         loadings : array-like
-            The loading matrix
+            The loading matrix.
 
         Returns
         -------
         gradient_dict : dict
-            A dictionary with
-            - grad : np.array
-                The gradient.
-            - criterion : float
-                The value of the criterion for the objective.
+            A dictionary containing the following keys:
+            (1) ``grad`` : :obj:`numpy.ndarray`, containing the gradients.
+            (2) ``criterion`` : float, containing the criterion for the objective.
         """
         p, k = loadings.shape
 
@@ -252,34 +245,39 @@ class Rotator(BaseEstimator):
         M = np.ones(p) - np.eye(p)
 
         loadings_squared = loadings**2
-        f1 = (1 - self.kappa) * np.sum(np.diag(np.dot(loadings_squared.T,
-                                                      np.dot(loadings_squared, N)))) / 4
-        f2 = self.kappa * np.sum(np.diag(np.dot(loadings_squared.T,
-                                                np.dot(M, loadings_squared)))) / 4
+        f1 = (
+            (1 - self.kappa)
+            * np.sum(np.diag(np.dot(loadings_squared.T, np.dot(loadings_squared, N))))
+            / 4
+        )
+        f2 = (
+            self.kappa
+            * np.sum(np.diag(np.dot(loadings_squared.T, np.dot(M, loadings_squared))))
+            / 4
+        )
 
-        gradient = ((1 - self.kappa) * loadings * np.dot(loadings_squared, N) +
-                    self.kappa * loadings * np.dot(M, loadings_squared))
+        gradient = (1 - self.kappa) * loadings * np.dot(
+            loadings_squared, N
+        ) + self.kappa * loadings * np.dot(M, loadings_squared)
 
         criterion = f1 + f2
-        return {'grad': gradient, 'criterion': criterion}
+        return {"grad": gradient, "criterion": criterion}
 
-    def _geomin_obj(self, loadings):
+    def _geomin_obj(self, loadings):  # noqa: D401
         """
-        Geomin function objective
+        The Geomin function objective.
 
         Parameters
         ----------
         loadings : array-like
-            The loading matrix
+            The loading matrix.
 
         Returns
         -------
         gradient_dict : dict
-            A dictionary with
-            - grad : np.array
-                The gradient.
-            - criterion : float
-                The value of the criterion for the objective.
+            A dictionary containing the following keys:
+            (1) ``grad`` : :obj:`numpy.ndarray`, containing the gradients.
+            (2) ``criterion`` : float, containing the criterion for the objective.
         """
         p, k = loadings.shape
 
@@ -290,14 +288,14 @@ class Rotator(BaseEstimator):
 
         gradient = (2 / k) * (loadings / loadings2) * rep
         criterion = np.sum(pro)
-        return {'grad': gradient, 'criterion': criterion}
+        return {"grad": gradient, "criterion": criterion}
 
     def _oblique(self, loadings, method):
         """
-        A generic function for performing
-        all oblique rotations, except for
-        promax, which is implemented
-        separately.
+        Perform oblique rotations, except 'promax'.
+
+        A generic function for performing all oblique rotations, except for
+        promax, which is implemented separately.
 
         Parameters
         ----------
@@ -308,25 +306,23 @@ class Rotator(BaseEstimator):
 
         Returns
         -------
-        loadings : numpy array, shape (n_features, n_factors)
+        loadings : :obj:`numpy.ndarray`, shape (``n_features``, ``n_factors``)
             The loadings matrix
-        rotation_mtx : numpy array, shape (n_factors, n_factors)
+        rotation_mtx : :obj:`numpy.ndarray`, shape (``n_factors``, ``n_factors``)
             The rotation matrix
-        psi : numpy array or None, shape (n_factors, n_factors)
-            The factor correlations
-            matrix. This only exists
-            if the rotation is oblique.
+        phi : :obj:`numpy.ndarray`, shape (``n_factors``, ``n_factors``)
+            The factor correlations matrix. This only exists if the
+            rotation is oblique.
         """
-
-        if method == 'oblimin':
+        if method == "oblimin":
             objective = self._oblimin_obj
-        elif method == 'quartimin':
+        elif method == "quartimin":
             objective = self._quartimin_obj
-        elif method == 'geomin_obl':
+        elif method == "geomin_obl":
             objective = self._geomin_obj
 
         # initialize the rotation matrix
-        n_rows, n_cols = loadings.shape
+        _, n_cols = loadings.shape
         rotation_matrix = np.eye(n_cols)
 
         # default alpha level
@@ -335,25 +331,26 @@ class Rotator(BaseEstimator):
         new_loadings = np.dot(loadings, rotation_matrix_inv.T)
 
         obj = objective(new_loadings)
-        gradient = -np.dot(new_loadings.T, np.dot(obj['grad'], rotation_matrix_inv)).T
-        criterion = obj['criterion']
+        gradient = -np.dot(new_loadings.T, np.dot(obj["grad"], rotation_matrix_inv)).T
+        criterion = obj["criterion"]
 
         obj_t = objective(new_loadings)
 
         # main iteration loop, up to `max_iter`, calculate the gradient
-        for i in range(0, self.max_iter + 1):
-            gradient_new = gradient - np.dot(rotation_matrix,
-                                             np.diag(np.dot(np.ones(gradient.shape[0]),
-                                                            rotation_matrix * gradient)))
+        for _ in range(0, self.max_iter + 1):
+            gradient_new = gradient - np.dot(
+                rotation_matrix,
+                np.diag(np.dot(np.ones(gradient.shape[0]), rotation_matrix * gradient)),
+            )
             s = np.sqrt(np.sum(np.diag(np.dot(gradient_new.T, gradient_new))))
 
-            if (s < self.tol):
+            if s < self.tol:
                 break
 
             alpha = 2 * alpha
 
             # calculate the Hessian of the objective function
-            for j in range(0, 11):
+            for _ in range(0, 11):
                 X = rotation_matrix - alpha * gradient_new
 
                 v = 1 / np.sqrt(np.dot(np.ones(X.shape[0]), X**2))
@@ -361,17 +358,19 @@ class Rotator(BaseEstimator):
                 new_loadings = np.dot(loadings, np.linalg.inv(new_rotation_matrix).T)
 
                 obj_t = objective(new_loadings)
-                improvement = criterion - obj_t['criterion']
+                improvement = criterion - obj_t["criterion"]
 
-                if (improvement > 0.5 * s**2 * alpha):
+                if improvement > 0.5 * s**2 * alpha:
                     break
 
                 alpha = alpha / 2
 
             rotation_matrix = new_rotation_matrix
-            criterion = obj_t['criterion']
-            gradient = -np.dot(np.dot(new_loadings.T, obj_t['grad']),
-                               np.linalg.inv(new_rotation_matrix)).T
+            criterion = obj_t["criterion"]
+            gradient = -np.dot(
+                np.dot(new_loadings.T, obj_t["grad"]),
+                np.linalg.inv(new_rotation_matrix),
+            ).T
 
         # calculate phi
         phi = np.dot(rotation_matrix.T, rotation_matrix)
@@ -382,39 +381,38 @@ class Rotator(BaseEstimator):
 
     def _orthogonal(self, loadings, method):
         """
-        A generic function for performing
-        all orthogonal rotations, except for
-        varimax, which is implemented
-        separately.
+        Perform orthogonal rotations, except 'varimax'.
+
+        A generic function for performing all orthogonal rotations, except for
+        varimax, which is implemented separately.
 
         Parameters
         ----------
-        loadings : numpy array
+        loadings : :obj:`numpy.ndarray`
             The loading matrix
         method : str
             The orthogonal rotation method to use.
 
         Returns
         -------
-        loadings : numpy array, shape (n_features, n_factors)
+        loadings : :obj:`numpy.ndarray`
             The loadings matrix
-        rotation_mtx : numpy array, shape (n_factors, n_factors)
+        rotation_mtx : :obj:`numpy.ndarray`, shape (``n_factors``, ``n_factors``)
             The rotation matrix
         """
-
-        if method == 'oblimax':
+        if method == "oblimax":
             objective = self._oblimax_obj
-        elif method == 'quartimax':
+        elif method == "quartimax":
             objective = self._quartimax_obj
-        elif method == 'equamax':
+        elif method == "equamax":
             objective = self._equamax_obj
-        elif method == 'geomin_ort':
+        elif method == "geomin_ort":
             objective = self._geomin_obj
 
         arr = loadings.copy()
 
         # initialize the rotation matrix
-        n_rows, n_cols = arr.shape
+        _, n_cols = arr.shape
         rotation_matrix = np.eye(n_cols)
 
         # default alpha level
@@ -422,40 +420,40 @@ class Rotator(BaseEstimator):
         new_loadings = np.dot(arr, rotation_matrix)
 
         obj = objective(new_loadings)
-        gradient = np.dot(arr.T, obj['grad'])
-        criterion = obj['criterion']
+        gradient = np.dot(arr.T, obj["grad"])
+        criterion = obj["criterion"]
 
         obj_t = objective(new_loadings)
 
         # main iteration loop, up to `max_iter`, calculate the gradient
-        for i in range(0, self.max_iter + 1):
+        for _ in range(0, self.max_iter + 1):
             M = np.dot(rotation_matrix.T, gradient)
             S = (M + M.T) / 2
             gradient_new = gradient - np.dot(rotation_matrix, S)
             s = np.sqrt(np.sum(np.diag(np.dot(gradient_new.T, gradient_new))))
 
-            if (s < self.tol):
+            if s < self.tol:
                 break
 
             alpha = 2 * alpha
 
             # calculate the Hessian of the objective function
-            for j in range(0, 11):
+            for _ in range(0, 11):
                 X = rotation_matrix - alpha * gradient_new
-                U, D, V = np.linalg.svd(X)
+                U, _, V = np.linalg.svd(X)
                 new_rotation_matrix = np.dot(U, V)
                 new_loadings = np.dot(arr, new_rotation_matrix)
 
                 obj_t = objective(new_loadings)
 
-                if (obj_t['criterion'] < (criterion - 0.5 * s**2 * alpha)):
+                if obj_t["criterion"] < (criterion - 0.5 * s**2 * alpha):
                     break
 
                 alpha = alpha / 2
 
             rotation_matrix = new_rotation_matrix
-            criterion = obj_t['criterion']
-            gradient = np.dot(arr.T, obj_t['grad'])
+            criterion = obj_t["criterion"]
+            gradient = np.dot(arr.T, obj_t["grad"])
 
         # convert loadings matrix to data frame
         loadings = new_loadings.copy()
@@ -463,20 +461,19 @@ class Rotator(BaseEstimator):
 
     def _varimax(self, loadings):
         """
-        Perform varimax (orthogonal) rotation, with optional
-        Kaiser normalization.
+        Perform varimax (orthogonal) rotation, with optional Kaiser normalization.
 
         Parameters
         ----------
         loadings : array-like
-            The loading matrix
+            The loading matrix.
 
         Returns
         -------
-        loadings : numpy array, shape (n_features, n_factors)
-            The loadings matrix
-        rotation_mtx : numpy array, shape (n_factors, n_factors)
-            The rotation matrix
+        loadings : :obj:`numpy.ndarray`, shape (``n_features``, ``n_factors``)
+            The loadings matrix.
+        rotation_mtx : :obj:`numpy.ndarray`, shape (``n_factors``, ``n_factors``)
+            The rotation matrix.
         """
         X = loadings.copy()
         n_rows, n_cols = X.shape
@@ -486,7 +483,9 @@ class Rotator(BaseEstimator):
         # normalize the loadings matrix
         # using sqrt of the sum of squares (Kaiser)
         if self.normalize:
-            normalized_mtx = np.apply_along_axis(lambda x: np.sqrt(np.sum(x**2)), 1, X.copy())
+            normalized_mtx = np.apply_along_axis(
+                lambda x: np.sqrt(np.sum(x**2)), 1, X.copy()
+            )
             X = (X.T / normalized_mtx).T
 
         # initialize the rotation matrix
@@ -535,8 +534,7 @@ class Rotator(BaseEstimator):
 
     def _promax(self, loadings):
         """
-        Perform promax (oblique) rotation, with optional
-        Kaiser normalization.
+        Perform promax (oblique) rotation, with optional Kaiser normalization.
 
         Parameters
         ----------
@@ -545,17 +543,16 @@ class Rotator(BaseEstimator):
 
         Returns
         -------
-        loadings : numpy array, shape (n_features, n_factors)
+        loadings : :obj:`numpy.ndarray`, shape (``n_features``, ``n_factors``)
             The loadings matrix
-        rotation_mtx : numpy array, shape (n_factors, n_factors)
+        rotation_mtx : :obj:`numpy.ndarray`, shape (``n_factors``, ``n_factors``)
             The rotation matrix
-        psi : numpy array or None, shape (n_factors, n_factors)
-            The factor correlations
-            matrix. This only exists
-            if the rotation is oblique.
+        phi : :obj:`numpy.ndarray` or None, shape (``n_factors``, ``n_factors``)
+            The factor correlations matrix. This only exists if the rotation
+            is oblique.
         """
         X = loadings.copy()
-        n_rows, n_cols = X.shape
+        _, n_cols = X.shape
         if n_cols < 2:
             return X
 
@@ -572,7 +569,7 @@ class Rotator(BaseEstimator):
 
         # first get varimax rotation
         X, rotation_mtx = self._varimax(weights)
-        Y = X * np.abs(X)**(self.power - 1)
+        Y = X * np.abs(X) ** (self.power - 1)
 
         # fit linear regression model
         coef = np.dot(np.linalg.inv(np.dot(X.T, X)), np.dot(X.T, Y))
@@ -603,13 +600,13 @@ class Rotator(BaseEstimator):
 
     def fit(self, X, y=None):
         """
-        Computes the factor rotation.
+        Compute the factor rotation.
 
         Parameters
         ----------
         X : array-like
-            The factor loading matrix (n_features, n_factors)
-        y : Ignored
+            The factor loading matrix, shape (``n_features``, ``n_factors``)
+        y : ignored
 
         Returns
         -------
@@ -630,26 +627,23 @@ class Rotator(BaseEstimator):
 
     def fit_transform(self, X, y=None):
         """
-        Computes the factor rotation,
-        and returns the new loading matrix.
+        Compute the factor rotation, and return the new loading matrix.
 
         Parameters
         ----------
         X : array-like
-            The factor loading matrix (n_features, n_factors)
+            The factor loading matrix, shape (``n_features``, ``n_factors``)
         y : Ignored
 
         Returns
         -------
-        loadings_ : numpy array, shape (n_features, n_factors)
-            The loadings matrix
-            (n_features, n_factors)
+        loadings_ : :obj:`numpy,ndarray`, shape (``n_features``, ``n_factors``)
+            The loadings matrix.
 
         Raises
         ------
         ValueError
-            If the `method` is not in the list of
-            acceptable methods.
+            If ``method`` is not in the list of acceptable methods.
 
         Example
         -------
@@ -676,29 +670,27 @@ class Rotator(BaseEstimator):
         # for oblique rotations
         phi = None
         method = self.method.lower()
-        if method == 'varimax':
-            (new_loadings,
-             new_rotation_mtx) = self._varimax(X)
+        if method == "varimax":
+            (new_loadings, new_rotation_mtx) = self._varimax(X)
 
-        elif method == 'promax':
-            (new_loadings,
-             new_rotation_mtx,
-             phi) = self._promax(X)
+        elif method == "promax":
+            (new_loadings, new_rotation_mtx, phi) = self._promax(X)
 
         elif method in OBLIQUE_ROTATIONS:
-            (new_loadings,
-             new_rotation_mtx,
-             phi) = self._oblique(X, method)
+            (new_loadings, new_rotation_mtx, phi) = self._oblique(X, method)
 
         elif method in ORTHOGONAL_ROTATIONS:
-            (new_loadings,
-             new_rotation_mtx) = self._orthogonal(X, method)
+            (new_loadings, new_rotation_mtx) = self._orthogonal(X, method)
 
         else:
-            raise ValueError("The value for `method` must be one of the "
-                             "following: {}.".format(', '.join(POSSIBLE_ROTATIONS)))
+            raise ValueError(
+                "The value for `method` must be one of the "
+                "following: {}.".format(", ".join(POSSIBLE_ROTATIONS))
+            )
 
-        (self.loadings_,
-         self.rotation_,
-         self.phi_) = new_loadings, new_rotation_mtx, phi
+        (self.loadings_, self.rotation_, self.phi_) = (
+            new_loadings,
+            new_rotation_mtx,
+            phi,
+        )
         return self.loadings_
